@@ -1,17 +1,18 @@
-from pandas import Series
 from typing import Optional
 
-from survey.mixins.data import DataMixin
+from pandas import Series
+
+from survey.attributes._abstract.respondent_attribute import RespondentAttribute
+from survey.mixins.data_mixins import NumericDataMixin
 from survey.mixins.data_types.continuous_1d_mixin import Continuous1dMixin
 from survey.mixins.data_validation.positive_measure_validation_mixin import \
     PositiveMeasureValidationMixin
 from survey.mixins.named import NamedMixin
-from survey.attributes._abstract.respondent_attribute import RespondentAttribute
 
 
 class PositiveMeasureAttribute(
     NamedMixin,
-    DataMixin,
+    NumericDataMixin,
     PositiveMeasureValidationMixin,
     Continuous1dMixin,
     RespondentAttribute
@@ -28,7 +29,12 @@ class PositiveMeasureAttribute(
         :param data: Optional pandas Series of responses.
         """
         self._set_name_and_text(name, text)
-        self._set_data(data)
+        if data is not None:
+            try:
+                data = data.astype(int)
+            except ValueError:
+                data = data.astype(float)
+        self.data = data
 
     def __repr__(self):
 
